@@ -2,6 +2,7 @@ import urllib
 import commands
 import os
 import bbricks.output
+import distutils.spawn
 import sys
 
 import SCons.Defaults
@@ -73,14 +74,15 @@ def download_lint_script():
         urllib.urlretrieve ("http://google-styleguide.googlecode.com/svn/trunk/cpplint/cpplint.py", cpplint_path)
         print 'downloading cpplint.py... done'
     except:
-        abort_exec("error: could not download 'cpplint.py' check your internet connection")
+        bbricks.output.abort_exec("error: could not download 'cpplint.py' check your internet connection")
 
     if not os.path.exists(cpplint_path):
-        abort_exec("error: could not download 'cppling.py' check your internet connection")
+        bbricks.output.abort_exec("error: could not download 'cpplint.py' check your internet connection")
 
 def setup_scons_lint(scons_env, target):
 
-    download_lint_script()
+    if distutils.spawn.find_executable('cpplint.py') is None:
+        bbricks.output.abort_exec("error: you do not have cpplint.py installed in your PATH. Download from: http://google-styleguide.googlecode.com")
 
     scons_env.bbricks_target = target
 
@@ -94,7 +96,7 @@ def setup_scons_lint(scons_env, target):
 
     scons_env.Append(BUILDERS={'Lint': linter})
     scons_env["PYTHON"] = sys.executable
-    scons_env["LINT"] = ".tmp/cpplint.py"
+    scons_env["LINT"] = "cpplint.py"
 
     lint_options = ["--verbose=3"]
 
